@@ -64,26 +64,31 @@ impl View for ContentView {
 
     fn draw(&mut self, w: &mut W, state: &mut AppState) -> Result<(), SafeClosetError> {
         self.clear(w)?;
-        match &mut state.drawer_state {
-            DrawerState::NoneOpen => {
-                if state.open_closet.just_created() && state.created_drawers == 0 {
-                    self.skin.md.write_in_area_on(w, MD_NEW_CLOSET, &self.area)?;
-                } else {
-                    self.skin.md.write_in_area_on(w, MD_NO_DRAWER_OPEN, &self.area)?;
+        if let Some(help_state) = &mut state.help {
+            help_state.set_area(self.area.clone());
+            help_state.draw(w)?;
+        } else {
+            match &mut state.drawer_state {
+                DrawerState::NoneOpen => {
+                    if state.open_closet.just_created() && state.created_drawers == 0 {
+                        self.skin.md.write_in_area_on(w, MD_NEW_CLOSET, &self.area)?;
+                    } else {
+                        self.skin.md.write_in_area_on(w, MD_NO_DRAWER_OPEN, &self.area)?;
+                    }
                 }
-            }
-            DrawerState::DrawerCreation(PasswordInputState { input }) => {
-                if state.open_closet.depth() > 0 {
-                    self.draw_password_input( w, input, MD_CREATE_DEEP_DRAWER)?;
-                } else {
-                    self.draw_password_input( w, input, MD_CREATE_TOP_DRAWER)?;
+                DrawerState::DrawerCreation(PasswordInputState { input }) => {
+                    if state.open_closet.depth() > 0 {
+                        self.draw_password_input( w, input, MD_CREATE_DEEP_DRAWER)?;
+                    } else {
+                        self.draw_password_input( w, input, MD_CREATE_TOP_DRAWER)?;
+                    }
+                }
+                DrawerState::DrawerOpening(PasswordInputState { input }) => {
+                    self.draw_password_input(w, input, MD_OPEN_DRAWER)?;
+                }
+                DrawerState::DrawerEdit(des) => {
+                    self.draw_drawer(w, des)?;
                 }
-            }
-            DrawerState::DrawerOpening(PasswordInputState { input }) => {
-                self.draw_password_input(w, input, MD_OPEN_DRAWER)?;
-            }
-            DrawerState::DrawerEdit(des) => {
-                self.draw_drawer(w, des)?;
             }
         }
         Ok(())
@@ -130,14 +135,18 @@ impl ContentView {
         let scrollbar = des.scrollbar();
         let name_width = layout.name_width as usize;
         let value_left = name_width + 2; // 1 for selection mark, one for '|'
-        let value_width = layout.lines_area.width as usize - value_left;
+        let value_width = layout.value_width();
         let tbl_style = self.skin.tbl_style(false);
         let normal_style = self.skin.txt_style(false);
         // -- header
         self.go_to_line(w, 1)?;
         tbl_style.queue_str(w, &"─".repeat(name_width + 1))?;
         tbl_style.queue_str(w, "┬")?;
-        let value_header_width = if scrollbar.is_some() { value_width + 1 } else { value_width };
+        let value_header_width = if scrollbar.is_some() {
+            value_width + 1
+        } else {
+            value_width
+        };
         tbl_style.queue_str(w, &"─".repeat(value_header_width))?;
         self.go_to_line(w, 2)?;
         if des.focus.is_search() {
@@ -146,7 +155,10 @@ impl ContentView {
             des.search.input.display_on(w)?;
         } else if des.search.has_content() {
             normal_style.queue_str(w, "/")?;
-            let (fitted, width) = StrFit::make_string(&des.search.input.get_content(), name_width.into());
+            let (fitted, width) = StrFit::make_string(
+                &des.search.input.get_content(),
+                name_width,
+            );
             normal_style.queue_str(w, fitted)?;
             if width < name_width {
                 tbl_style.queue_str(w, &" ".repeat(name_width - width))?;
@@ -241,7 +253,7 @@ impl ContentView {
                         self.skin.sel_md.write_composite_fill(
                             w,
                             Composite::from_inline(first_line),
-                            value_width.into(),
+                            value_width,
                             Alignment::Left,
                         )?;
                     }
@@ -252,7 +264,7 @@ impl ContentView {
                     self.skin.md.write_composite_fill(
                         w,
                         Composite::from_inline(first_line),
-                        value_width.into(),
+                        value_width,
                         Alignment::Left,
                     )?;
                 }
